==> uniq-1.2.0.25-py3-none-any.whl: uniq/apis/nb/clients/network_plug_and_play_client/models/CertificateInfo.py <==
#!/usr/bin/env python
#pylint: skip-file
"""
Copyright 2016 Cisco Systems

Licensed under the Apache License, Version 2.0 (the "License");
you may not use this file except in compliance with the License.
You may obtain a copy of the License at

    http://www.apache.org/licenses/LICENSE-2.0

Unless required by applicable law or agreed to in writing, software
distributed under the License is distributed on an "AS IS" BASIS,
WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
See the License for the specific language governing permissions and
limitations under the License.
"""

class CertificateInfo(object):



    def __init__(self):
        """
        Attributes:
          swaggerTypes (dict): The key is attribute name and the value is attribute type.
          attributeMap (dict): The key is attribute name and the value is json key in definition.
        """
        self.swaggerTypes = {

            'keySize': 'int',


            'signature': 'str',


            'serialNumber': 'str',


            'issuerDN': 'str',


            'subjectDN': 'str',


            'keyType': 'str',


            'beginDate': 'str',


            'noAfterDate': 'str'

        }

        self.attributeMap = {

            'keySize': 'keySize',

            'signature': 'signature',

            'serialNumber': 'serialNumber',

            'issuerDN': 'issuerDN',

            'subjectDN': 'subjectDN',

            'keyType': 'keyType',

            'beginDate': 'beginDate',

            'noAfterDate': 'noAfterDate'

        }



        self.keySize = None # int


        self.signature = None # str


        self.serialNumber = None # str


        self.issuerDN = None # str


        self.subjectDN = None # str


        self.keyType = None # str


        self.beginDate = None # str


        self.noAfterDate = None # str

==> uniq-1.3.2.30-py3-none-any.whl: uniq/apis/nb/clients/network_plug_and_play_client/models/CertificateInfo.py <==
#!/usr/bin/env python
#pylint: skip-file
# This source code is licensed under the Apache license found in the
# LICENSE file in the root directory of this project.


class CertificateInfo(object):


    def __init__(self):
        """
        Attributes:
          swaggerTypes (dict): The key is attribute name and the value is attribute type.
          attributeMap (dict): The key is attribute name and the value is json key in definition.
        """
        self.swaggerTypes = {
            
            'keySize': 'int',
            
            
            'serialNumber': 'str',
            
            
            'issuerDN': 'str',
            
            
            'subjectDN': 'str',
            
            
            'keyType': 'str',
            
            
            'noAfterDateISO8601': 'str',
            
            
            'noAfterDate': 'str',
            
            
            'beginDateISO8601': 'str',
            
            
            'beginDate': 'str',
            
            
            'signature': 'str'
            
        }

        self.attributeMap = {
            
            'keySize': 'keySize',
            
            'serialNumber': 'serialNumber',
            
            'issuerDN': 'issuerDN',
            
            'subjectDN': 'subjectDN',
            
            'keyType': 'keyType',
            
            'noAfterDateISO8601': 'noAfterDateISO8601',
            
            'noAfterDate': 'noAfterDate',
            
            'beginDateISO8601': 'beginDateISO8601',
            
            'beginDate': 'beginDate',
            
            'signature': 'signature'
            
        }       

        
        
        self.keySize = None # int
        
        
        self.serialNumber = None # str
        
        
        self.issuerDN = None # str
        
        
        self.subjectDN = None # str
        
        
        self.keyType = None # str
        
        
        self.noAfterDateISO8601 = None # str
        
        
        self.noAfterDate = None # str
        
        
        self.beginDateISO8601 = None # str
        
        
        self.beginDate = None # str
        
        
        self.signature = None # str
